def add_num(num1, num2):
    return num1 + num2

def sub_numb(num1, num2):
    return num1 - num2

def mul_num(num1, num2):
    return num1 * num2

def div_num(num1, num2):
    return num1 / num2

def mod_num(num1, num2):
    return num1 % num2